@@ -15,10 +15,10 @@
 """Client for interacting with the Google Cloud Storage API."""
 
 
+from google.api.core import page_iterator
 from google.cloud._helpers import _LocalStack
 from google.cloud.client import ClientWithProject
 from google.cloud.exceptions import NotFound
-from google.cloud.iterator import HTTPIterator
 from google.cloud.storage._http import Connection
 from google.cloud.storage.batch import Batch
 from google.cloud.storage.bucket import Bucket
@@ -255,7 +255,7 @@ class Client(ClientWithProject):
             response with just the next page token and the language of each
             bucket returned: 'items/id,nextPageToken'
 
-        :rtype: :class:`~google.cloud.iterator.Iterator`
+        :rtype: :class:`~google.api.core.page_iterator.Iterator`
         :returns: Iterator of all :class:`~google.cloud.storage.bucket.Bucket`
                   belonging to this project.
         """
@@ -269,16 +269,20 @@ class Client(ClientWithProject):
         if fields is not None:
             extra_params['fields'] = fields
 
-        return HTTPIterator(
-            client=self, path='/b', item_to_value=_item_to_bucket,
-            page_token=page_token, max_results=max_results,
+        return page_iterator.HTTPIterator(
+            client=self,
+            api_request=self._connection.api_request,
+            path='/b',
+            item_to_value=_item_to_bucket,
+            page_token=page_token,
+            max_results=max_results,
             extra_params=extra_params)
 
 
 def _item_to_bucket(iterator, item):
     """Convert a JSON bucket to the native object.
 
-    :type iterator: :class:`~google.cloud.iterator.Iterator`
+    :type iterator: :class:`~google.api.core.page_iterator.Iterator`
     :param iterator: The iterator that has retrieved the item.
 
     :type item: dict
