@@ -404,13 +404,13 @@ class TestClient(unittest.TestCase):
         self.assertEqual(parse_qs(uri_parts.query), expected_query)
 
     def test_page_empty_response(self):
-        from google.cloud.iterator import Page
+        from google.api.core import page_iterator
 
         project = 'PROJECT'
         credentials = _make_credentials()
         client = self._make_one(project=project, credentials=credentials)
         iterator = client.list_buckets()
-        page = Page(iterator, (), None)
+        page = page_iterator.Page(iterator, (), None)
         iterator._page = page
         self.assertEqual(list(page), [])
 
